# gcandle 轻量极速的本地量化交易框架

目前针对A股。

## 可以做什么
使用本框架可以轻松开发出你自己的量化模型。设计良好的API可以让你专注于交易模型的开发，最大限度减小无关的工作量。请看示例项目。
本框架包含数据下载，指标开发，策略回测分析的完整功能。实盘交易暂不包含，本地实盘可以参考easytrader等方案，但量化交易的核心，应该是策略模型。
有了模型，还怕没办法交易么？至于在线方案，我本人是不放心策略安全的。
用本框架开发的模型，可以把选出的股票用其他任何实盘方案实现交易，同时模型却是绝对安全的，因为你对交易软件的输入只会是你模型的结果。

## 轻量
代码优雅紧凑，可以轻松看完全部代码，也可轻易扩展功能。

## 极速
速度为什么重要，因为策略需要不停的调试。
首先数据在本地。在线方案要做一个复杂的策略模型，对全市场进行扫描计算，几乎是不可能完成的任务，时间太长。
本框架封装了多进程的指标计算，根据主要指标对全市场数据过滤后，保存基本的股票池和策略关心的指标，再用回测框架调试不同的指标组合及参数，几年的全市场扫描回测只需要几十秒。
当然前提是你的电脑不能太差，对单核cpu就没什么用了。

## 为什么做这个框架
因为找不到满足我需求的框架，即上述两个条件都满足的。

## 开始使用

